@@ -1,4 +1,4 @@
-//  
+//
 //  Copyright (c) 1997 by Mike Romberg ( romberg@fsl.noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
@@ -9,16 +9,17 @@
 #ifndef _BTRYMETER_H_
 #define _BTRYMETER_H_
 
-
+#include "defines.h"
 #include "fieldmeter.h"
 
+#ifdef HAVE_BATTERY_METER
 
 class BtryMeter : public FieldMeter {
 public:
   BtryMeter( XOSView *parent );
   ~BtryMeter( void );
 
-  const char *name( void ) const { return "BtryMeter"; }  
+  const char *name( void ) const { return "BtryMeter"; }
   void checkevent( void );
 
   void checkResources( void );
@@ -29,5 +30,6 @@ private:
   int alarmThreshold;
 };
 
+#endif  // HAVE_BATTERY_METER
 
 #endif
