@@ -2,7 +2,7 @@
 #define __kernel_h__
 
 //
-//  NetBSD port:  
+//  NetBSD port:
 //  Copyright (c) 1995, 1996, 1997-2002 by Brian Grayson (bgrayson@netbsd.org)
 //
 //  This file was written by Brian Grayson for the NetBSD and xosview
@@ -14,61 +14,51 @@
 //    authors for a copy.
 //
 
+#include <sys/types.h>
+#include "defines.h"
+
 void
 BSDInit();
 
 void
-SetKernelName(const char* const kernelName);
+SetKernelName(const char* kernelName);
+
+int
+BSDGetCPUSpeed();
 
 void
 BSDPageInit();
 
-#if defined(UVM)
 void
-BSDGetUVMPageStats(struct uvmexp* uvmp);
-#else
-void
-BSDGetPageStats(struct vmmeter* vmp);
-#endif
+BSDGetPageStats(u_int64_t *meminfo, u_int64_t *pageinfo);
 
 void
 BSDCPUInit();
 
-#if defined(XOSVIEW_NETBSD) && (__NetBSD_Version__ >= 104260000)
 void
-BSDGetCPUTimes(u_int64_t* timesArray);
+#if defined(XOSVIEW_NETBSD) || defined(XOSVIEW_DFBSD)
+BSDGetCPUTimes(u_int64_t *timesArray);
 #else
-void
-BSDGetCPUTimes(long* timesArray);
+BSDGetCPUTimes(long *timesArray);
 #endif
 
 int
 BSDNetInit();
 
 void
-BSDGetNetInOut (long long * inbytes, long long * outbytes);
+BSDGetNetInOut(unsigned long long *inbytes, unsigned long long *outbytes, const char *netIface, bool ignored);
 
 int
 BSDSwapInit();
 
-#ifdef HAVE_SWAPCTL
 void
-BSDGetSwapCtlInfo(unsigned long long* total, unsigned long long* free);
-#endif
+BSDGetSwapInfo(u_int64_t* total, u_int64_t* free);
 
 int
 BSDDiskInit();
 
-void
-BSDGetDiskXFerBytes (unsigned long long * bytes);
-
-#ifdef XOSVIEW_FREEBSD
-void
-FreeBSDGetBufspace(int* bfsp);
-#endif
-
-
-#define NUM_INTR	16
+u_int64_t
+BSDGetDiskXFerBytes(u_int64_t *read_bytes, u_int64_t *write_bytes);
 
 int
 BSDIntrInit();
@@ -77,6 +67,16 @@ int
 BSDNumInts();
 
 void
-BSDGetIntrStats (unsigned long intrCount[NUM_INTR]);
+BSDGetIntrStats(unsigned long *intrCount, unsigned int *intrNbrs);
+
+int
+BSDCountCpus(void);
+
+void
+BSDGetCPUTemperature(float *temps, float *tjmax);
+
+void
+BSDGetSensor(const char *name, const char *valname, float *value);
+
 
 #endif
