@@ -28,7 +28,7 @@ static const char ACPIBATTERYDIR[] = "/proc/acpi/battery";
 static const char SYSPOWERDIR[] = "/sys/class/power_supply";
 
 BtryMeter::BtryMeter( XOSView *parent )
-  : FieldMeter( parent, 2, "BTRY", "AVAIL/USED", 1, 1, 0 ){
+  : FieldMeter( parent, 2, "BTRY", "CHRG/USED", 1, 1, 0 ){
 
   // find out ONCE whether to use ACPI, APM or sysfs
   use_acpi = use_apm = use_syspower = false;
@@ -113,23 +113,35 @@ bool BtryMeter::has_syspower( void ){
   bool found;
   DIR *dir;
   struct dirent *dp;
+  struct stat buf;
+  char dirname[80], f[80];
+  std::ifstream type;
+  std::string t;
 
   dir = opendir(SYSPOWERDIR);
   if (dir == NULL)
       return false;
 
   found = false;
-  while (!found) {
-      dp = readdir(dir);
-      if (dp == NULL)
-          break;
-
-      if (strncmp(dp->d_name, "BAT", 3) == 0) {
+  while (!found && (dp = readdir(dir))) {
+    if (!strncmp(dp->d_name, ".", 1))
+      continue;
+    if (!strncmp(dp->d_name, "..", 2))
+      continue;
+    snprintf(dirname, 80, "%s/%s", SYSPOWERDIR, dp->d_name);
+    if (stat(dirname, &buf) == 0 && S_ISDIR(buf.st_mode)) {
+      snprintf(f, 80, "%s/%s", dirname, "/type");
+      type.open(f);
+      if (type.good()) {
+        type >> t;
+        if (strncmp(t.c_str(), "Battery", 7) == 0) {
           found = true;
           break;
+        }
       }
+      type.close();
+    }
   }
-
   if (closedir(dir) != 0)
       abort();
 
@@ -339,7 +351,7 @@ bool BtryMeter::getapminfo( void ){
   // If the battery status is reported as a negative number, it means we are
   // running on AC power and no battery status is available - Report it as
   // completely empty (0). (Refer to Debian bug report #281565)
-  if (fields_[0] < 0) 
+  if (fields_[0] < 0)
     fields_[0] = 0;
 
   total_ = 100;
@@ -472,7 +484,7 @@ bool BtryMeter::acpi_battery_present(const std::string& filename)
 	argname.clear(); argval.clear();
 	loadinfo >> argname >> argval;
 
-	//XOSDEBUG("batt ?: a=\"%s\" v=\"%s\"\n",argname.c_str(),argval.c_str() );
+	XOSDEBUG("batt ?: a=\"%s\" v=\"%s\"\n",argname.c_str(),argval.c_str() );
 	if ( argname == "present:" )
            if ( argval == "yes" )
 		return true;
@@ -501,7 +513,7 @@ bool BtryMeter::acpi_parse_battery(const std::string& dirname)
 	inp_strm.str(inp_line.c_str() );
 	argname.clear(); argval.clear();
 	inp_strm >> argname >> argval;
-	//XOSDEBUG("alarm: a=\"%s\" v=\"%s\"\n",argname.c_str(),argval.c_str() );
+	XOSDEBUG("alarm: a=\"%s\" v=\"%s\"\n",argname.c_str(),argval.c_str() );
 
 	if ( argname == "alarm:" ) {
 		battery.alarm = atoi(argval.c_str());
@@ -520,7 +532,7 @@ bool BtryMeter::acpi_parse_battery(const std::string& dirname)
 	argval.clear();
 	std::getline(loadinfo,argval);
 
-	//XOSDEBUG("info: a=\"%s\" v=\"%s\"\n",argname.c_str(),argval.c_str() );
+	XOSDEBUG("info: a=\"%s\" v=\"%s\"\n",argname.c_str(),argval.c_str() );
 
 	if ( argname == "design capacity" ) {
 		battery.design_capacity=atoi(argval.c_str() );
@@ -552,7 +564,7 @@ bool BtryMeter::acpi_parse_battery(const std::string& dirname)
 	argval.clear();
 	inp_strm >> argval; // this ignores leading spaces
 
-	//XOSDEBUG("state: a=\"%s\" v=\"%s\"\n",argname.c_str(),argval.c_str() );
+	XOSDEBUG("state: a=\"%s\" v=\"%s\"\n",argname.c_str(),argval.c_str() );
 
 	if ( argname == "charging state" ) {
 		if ( argval == "charged" )
@@ -609,7 +621,7 @@ bool BtryMeter::sys_parse_battery(const std::string& dirname)
   while ( loadinfo.good() ) {
 	value.clear();
 	loadinfo >> value;
-	//XOSDEBUG("alarm (%s): v=\"%s\"\n", filename.c_str(), value.c_str() );
+	XOSDEBUG("alarm (%s): v=\"%s\"\n", filename.c_str(), value.c_str() );
     battery.alarm = atoi(value.c_str());
     break;
   }
@@ -623,7 +635,7 @@ bool BtryMeter::sys_parse_battery(const std::string& dirname)
   while ( loadinfo.good() ) {
 	value.clear();
 	loadinfo >> value;
-	//XOSDEBUG("design_capacity (%s): v=\"%s\"\n", filename.c_str(), value.c_str() );
+	XOSDEBUG("design_capacity (%s): v=\"%s\"\n", filename.c_str(), value.c_str() );
     battery.design_capacity = atoi(value.c_str());
     break;
   }
@@ -644,7 +656,7 @@ bool BtryMeter::sys_parse_battery(const std::string& dirname)
   while ( loadinfo.good() ) {
 	value.clear();
 	loadinfo >> value;
-	//XOSDEBUG("last_full_capacity (%s): v=\"%s\"\n", filename.c_str(), value.c_str() );
+	XOSDEBUG("last_full_capacity (%s): v=\"%s\"\n", filename.c_str(), value.c_str() );
     battery.last_full_capacity = atoi(value.c_str());
     break;
   }
@@ -658,7 +670,7 @@ bool BtryMeter::sys_parse_battery(const std::string& dirname)
   while ( loadinfo.good() ) {
 	value.clear();
 	loadinfo >> value;
-	//XOSDEBUG("remaining_capacity (%s): v=\"%s\"\n", filename.c_str(), value.c_str() );
+	XOSDEBUG("remaining_capacity (%s): v=\"%s\"\n", filename.c_str(), value.c_str() );
     battery.remaining_capacity = atoi(value.c_str());
     break;
   }
@@ -670,7 +682,7 @@ bool BtryMeter::sys_parse_battery(const std::string& dirname)
   while ( loadinfo.good() ) {
 	value.clear();
 	loadinfo >> value;
-	//XOSDEBUG("status (%s): v=\"%s\"\n", filename.c_str(), value.c_str() );
+	XOSDEBUG("status (%s): v=\"%s\"\n", filename.c_str(), value.c_str() );
 
     if ( value == "Full" )
         battery.charging_state=0;
