@@ -24,6 +24,7 @@
 
 
 #include "netmeter.h"
+#include "cpumeter.h"
 #include "xosview.h"
 
 #include <unistd.h>
@@ -49,6 +50,7 @@ NetMeter::NetMeter( XOSView *parent, float max )
   maxpackets_ = max;
   _lastBytesIn = _lastBytesOut = 0;
   _usechains = false;
+  ignored_ = false;
 
   checkOSVersion();
 }
@@ -59,22 +61,7 @@ NetMeter::~NetMeter( void ){
 
 void NetMeter::checkOSVersion(void)
     {
-    std::ifstream ifs("/proc/sys/kernel/osrelease");
-    if (!ifs)
-        {
-        std::cerr <<"Can not open file : " << "/proc/sys/kernel/osrelease"
-          << std::endl;
-        exit(1);
-        }
-
-    int major, minor;
-    _bytesInDev = 0;
-    ifs >> major;
-    ifs.ignore(1);
-    ifs >> minor;
-    ifs.ignore(1);
-
-    if (major > 2 || (major == 2 && minor >= 1))
+    if (CPUMeter::getkernelversion() >= 2001000)
         {
 	// check presence of iacct and oacct chains
         std::ifstream chains("/proc/net/ip_fwchains");
@@ -117,6 +104,10 @@ void NetMeter::checkResources( void ){
   dodecay_ = parent_->isResourceTrue( "netDecay" );
   SetUsedFormat (parent_->getResource("netUsedFormat"));
   netIface_ = parent_->getResource( "netIface" );
+  if (netIface_[0] == '-') {
+    ignored_ = true;
+    netIface_.erase(0, netIface_.find_first_not_of("- "));
+  }
 
   _ipsock = socket(AF_INET, SOCK_DGRAM, 0);
   if (_ipsock == -1) {
@@ -175,7 +166,7 @@ void NetMeter::checkeventNew(void)
 
 	  while (ifs)
 	      {
-		if (netIface_ == "False" ) 
+		if (netIface_ == "False" )
 		  {
 		    ifs.ignore(1024, ':');
 		  }
@@ -185,7 +176,7 @@ void NetMeter::checkeventNew(void)
 		    ifname = buf;
 		    ifs.ignore(1, ':');
 		    ifname.erase(0, ifname.find_first_not_of(" ") );
-		    if (ifname != netIface_) 
+		    if ( (!ignored_ && ifname != netIface_) || (ignored_ && ifname == netIface_) )
 		      {
 			ifs.ignore(1024,'\n');
 			continue;
