@@ -10,16 +10,6 @@
 #include <sstream>
 #include <stdlib.h>
 
-#ifdef USESYSCALLS
-#if defined(GNULIBC) || defined(__GLIBC__)
-#include <sys/sysinfo.h>
-#else
-#include <syscall.h>
-#include <linux/kernel.h>
-#endif
-#endif
-
-
 static const char MEMFILENAME[] = "/proc/meminfo";
 
 
@@ -48,34 +38,6 @@ void SwapMeter::checkevent( void ){
 }
 
 
-#ifdef USESYSCALLS
-void SwapMeter::getswapinfo( void ){
-  struct sysinfo sinfo;
-  unsigned long unit;
-
-#if defined(GNULIBC) || defined(__GLIBC__)
-  sysinfo(&sinfo);
-#else
-  syscall( SYS_sysinfo, &sinfo );
-#endif
-
-  unit = (sinfo.mem_unit ? sinfo.mem_unit : 1);
-
-  total_ = (double)sinfo.totalswap * unit;
-  fields_[0] = (double)(sinfo.totalswap - sinfo.freeswap) * unit;
-  fields_[1] = (double)sinfo.freeswap * unit;
-
-  if ( total_ == 0 ){
-    total_ = 1;
-    fields_[0] = 0;
-    fields_[1] = 1;
-  }
-
-  if (total_)
-    setUsed (fields_[0], total_);
-
-}
-#else
 void SwapMeter::getswapinfo( void ){
   std::ifstream meminfo( MEMFILENAME );
   if ( !meminfo ){
@@ -86,18 +48,31 @@ void SwapMeter::getswapinfo( void ){
   total_ = fields_[0] = fields_[1] = 0;
 
   char buf[256];
-  std::string ignore;
+  std::string ignore, unit;
 
   // Get the info from the "standard" meminfo file.
   while (!meminfo.eof()){
     meminfo.getline(buf, 256);
     std::istringstream line(std::string(buf, 256));
 
-    if(!strncmp("SwapTotal", buf, strlen("SwapTotal")))
-        line >> ignore >> total_;
-
-    if(!strncmp("SwapFree", buf, strlen("SwapFree")))
-        line >> ignore >> fields_[1];
+    if(!strncmp("SwapTotal", buf, strlen("SwapTotal"))){
+      line >> ignore >> total_ >> unit;
+      if (strncasecmp(unit.c_str(), "kB", 2) == 0)
+        total_ *= 1024.0;
+      if (strncasecmp(unit.c_str(), "MB", 2) == 0)
+        total_ *= 1024.0*1024.0;
+      if (strncasecmp(unit.c_str(), "GB", 2) == 0)
+        total_ *= 1024.0*1024.0*1024.0;
+    }
+    if(!strncmp("SwapFree", buf, strlen("SwapFree"))){
+      line >> ignore >> fields_[1] >> unit;
+      if (strncasecmp(unit.c_str(), "kB", 2) == 0)
+        fields_[1] *= 1024.0;
+      if (strncasecmp(unit.c_str(), "MB", 2) == 0)
+        fields_[1] *= 1024.0*1024.0;
+      if (strncasecmp(unit.c_str(), "GB", 2) == 0)
+        fields_[1] *= 1024.0*1024.0*1024.0;
+    }
   }
 
   fields_[0] = total_ - fields_[1];
@@ -111,4 +86,3 @@ void SwapMeter::getswapinfo( void ){
   if (total_)
     setUsed (fields_[0], total_);
 }
-#endif
