@@ -26,7 +26,6 @@ public:
   void reallydraw( void );
   void draw ( void );
   void run( void );
-  void keyrelease( char *ch );
   const char *winname( void );
 
   // used by meter makers
@@ -67,7 +66,7 @@ protected:
   void dolegends( void );
 
   void checkOverallResources();
-  void resizeEvent( XEvent & );
+  void resizeEvent( XConfigureEvent &event );
   void exposeEvent( XExposeEvent &event );
   void keyPressEvent( XKeyEvent &event );
   void visibilityEvent( XVisibilityEvent &event );
@@ -78,10 +77,17 @@ private:
 
   bool _isvisible;
   bool _ispartiallyvisible;
+  bool _defer_resize;
+  bool _defer_draw;
 };
 
-/*  Make XOSDEBUG("This is a format string.  %d %d\n", a, b); look
- *  like if (0) printf("This ..."...);.  Change the 0 to a 1, to
- *  enable these debugging outputs.  */
-#define XOSDEBUG	if (0) printf
+#ifdef DEBUG
+#define XOSDEBUG(...) { \
+  fprintf(stderr, "%s:%d: ", __func__, __LINE__); \
+  fprintf(stderr, __VA_ARGS__); \
+}
+#else
+#define XOSDEBUG(...)
+#endif
+
 #endif
