@@ -46,7 +46,6 @@ void XWin::XWinInit (int argc, char** argv, char* geometry, Xrm* xrm) {
 
   // Set up the default Events
   events_ = NULL;
-  addEvent( new Event( this, ConfigureNotify, &XWin::configureEvent ) );
   addEvent( new Event( this, ClientMessage, &XWin::deleteEvent ) );
   addEvent( new Event( this, MappingNotify, &XWin::mappingNotify ) );
 
@@ -108,22 +107,6 @@ void XWin::init( int argc, char **argv ){
   XChangeWindowAttributes(display_, window_,
 			  (CWColormap | CWBitGravity), &xswa);
 
-#ifdef HAVE_XPM
-  Pixmap background_pixmap;
-
-  // If there is a pixmap file, set it as the background
-  if(getPixmap(&background_pixmap))
-  {
-	XSetWindowBackgroundPixmap(display_,window_,background_pixmap);
-  }
-#endif
-
-  // Do transparency if requested
-  if(isResourceTrue("transparent"))
-  {
-        XSetWindowBackgroundPixmap(display_,window_,ParentRelative);
-  }
-
   // add the events
   Event *tmp = events_;
   while ( tmp != NULL ){
@@ -234,61 +217,6 @@ void XWin::setColors( void ){
 }
 //-----------------------------------------------------------------------------
 
-int XWin::getPixmap(Pixmap *pixmap)
-{
-#ifdef HAVE_XPM
-	char	*pixmap_file;
-	XWindowAttributes    root_att;
-	XpmAttributes        pixmap_att;
-
-//	if (isResourceTrue("transparent"))
-//	{
-//		Atom act_type;
-//		int act_format;
-//		unsigned long nitems, bytes_after;
-//		unsigned char *prop = NULL;
-//
-//		if (XGetWindowProperty(display_, window_,
-//		                       XInternAtom (display_, "_XROOTPMAP_ID", True),
-//		                       0, 1, False, XA_PIXMAP, &act_type, &act_format,
-//		                       &nitems, &bytes_after, &prop) != Success)
-//		{
-//			cerr << "Unable to get root window pixmap" << endl;
-//			cerr << "Defaulting to blank" << endl;
-//			pixmap=NULL;
-//			return 0; // OOps
-//		}
-//
-//		pixmap = (Pixmap *) prop;
-//		XFree (prop);
-//		return 1;  // Good, got the pixmap of the root window
-//	}
-
-	pixmap_file = (char*) getResourceOrUseDefault("pixmapName",NULL);
-
-	if (pixmap_file)
-	{
-		XGetWindowAttributes(display_, DefaultRootWindow(display_),&root_att);
-		pixmap_att.closeness=30000;
-		pixmap_att.colormap=root_att.colormap;
-		pixmap_att.valuemask=XpmSize|XpmReturnPixels|XpmColormap|XpmCloseness;
-		if(XpmReadFileToPixmap(display_,DefaultRootWindow(display_),pixmap_file, pixmap, NULL, &pixmap_att))
-        	{
-                	std::cerr << "Pixmap " << pixmap_file  << " not found" << std::endl;
-                	std::cerr << "Defaulting to blank" << std::endl;
-                	pixmap=NULL;
-			return 0; // OOps
-        	}
-		return 1;  // Good, found the pixmap
-  	}
-	return 0; // No file specified, none used
-#else
-	(void) pixmap;
-	std::cerr << "Error:  getPixmap called, when Xpm is not enabled!\n" ;
-	return 0;
-#endif
-}
-
 void XWin::getGeometry( void ){
   char                 default_geometry[80];
   int                  bitmask;
@@ -370,14 +298,6 @@ void XWin::checkevent( void ){
   }
 }
 //-----------------------------------------------------------------------------
-#if 0
-void XWin::usage( void ){
-  //  FIXME  We need to update this.  BCG
-  std::cerr <<name_ <<" [-display name] [-geometry geom]" <<std::endl;
-//    exit (1);
-}
-#endif
-//-----------------------------------------------------------------------------
 
 void XWin::addEvent( Event *event ){
   Event *tmp = events_;
@@ -434,14 +354,6 @@ unsigned long XWin::allocColor( const char *name ){
 }
 //-----------------------------------------------------------------------------
 
-void XWin::configureEvent( XEvent &event ){
-  x( event.xconfigure.x );
-  y( event.xconfigure.y );
-  width( event.xconfigure.width );
-  height( event.xconfigure.height );
-}
-//-----------------------------------------------------------------------------
-
 void XWin::deleteEvent( XEvent &event ){
   if ( (event.xclient.message_type == wm_ ) &&
        ((unsigned)event.xclient.data.l[0] == wmdelete_) )
